Struct scale_info::prelude::collections::hash_map::RandomState
1.7.0 · source · [−]pub struct RandomState { /* private fields */ }Expand description
RandomState is the default state for HashMap types.
A particular instance RandomState will create the same instances of
Hasher, but the hashers created by two different RandomState
instances are unlikely to produce the same result for the same values.
Examples
use std::collections::HashMap;
use std::collections::hash_map::RandomState;
let s = RandomState::new();
let mut map = HashMap::with_hasher(s);
map.insert(1, 2);Implementations
sourceimpl RandomState
impl RandomState
sourcepub fn new() -> RandomState
pub fn new() -> RandomState
Constructs a new RandomState that is initialized with random keys.
Examples
use std::collections::hash_map::RandomState;
let s = RandomState::new();Trait Implementations
sourceimpl BuildHasher for RandomState
impl BuildHasher for RandomState
type Hasher = DefaultHasher
type Hasher = DefaultHasher
Type of the hasher that will be created.
sourcefn build_hasher(&self) -> DefaultHasher
fn build_hasher(&self) -> DefaultHasher
Creates a new hasher. Read more
sourceimpl Clone for RandomState
impl Clone for RandomState
sourcefn clone(&self) -> RandomState
fn clone(&self) -> RandomState
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
1.16.0 · sourceimpl Debug for RandomState
impl Debug for RandomState
sourceimpl Default for RandomState
impl Default for RandomState
sourcefn default() -> RandomState
fn default() -> RandomState
Constructs a new RandomState.