pub struct RangeTo<Idx> {
pub end: Idx,
}Expand description
A range only bounded exclusively above (..end).
The RangeTo ..end contains all values with x < end.
It cannot serve as an Iterator because it doesn’t have a starting point.
Examples
The ..end syntax is a RangeTo:
assert_eq!((..5), std::ops::RangeTo { end: 5 });It does not have an IntoIterator implementation, so you can’t use it in
a for loop directly. This won’t compile:
// error[E0277]: the trait bound `std::ops::RangeTo<{integer}>:
// std::iter::Iterator` is not satisfied
for i in ..5 {
// ...
}When used as a slicing index, RangeTo produces a slice of all array
elements before the index indicated by end.
let arr = [0, 1, 2, 3, 4];
assert_eq!(arr[ .. ], [0, 1, 2, 3, 4]);
assert_eq!(arr[ .. 3], [0, 1, 2 ]); // This is a `RangeTo`
assert_eq!(arr[ ..=3], [0, 1, 2, 3 ]);
assert_eq!(arr[1.. ], [ 1, 2, 3, 4]);
assert_eq!(arr[1.. 3], [ 1, 2 ]);
assert_eq!(arr[1..=3], [ 1, 2, 3 ]);Fields
end: IdxThe upper bound of the range (exclusive).
Implementations
sourceimpl<Idx> RangeTo<Idx> where
Idx: PartialOrd<Idx>,
impl<Idx> RangeTo<Idx> where
Idx: PartialOrd<Idx>,
1.35.0 · sourcepub fn contains<U>(&self, item: &U) -> bool where
Idx: PartialOrd<U>,
U: PartialOrd<Idx> + ?Sized,
pub fn contains<U>(&self, item: &U) -> bool where
Idx: PartialOrd<U>,
U: PartialOrd<Idx> + ?Sized,
Returns true if item is contained in the range.
Examples
assert!( (..5).contains(&-1_000_000_000));
assert!( (..5).contains(&4));
assert!(!(..5).contains(&5));
assert!( (..1.0).contains(&0.5));
assert!(!(..1.0).contains(&f32::NAN));
assert!(!(..f32::NAN).contains(&0.5));Trait Implementations
sourceimpl<'a, T, O> BitSliceIndex<'a, T, O> for RangeTo<usize> where
O: BitOrder,
T: BitStore,
impl<'a, T, O> BitSliceIndex<'a, T, O> for RangeTo<usize> where
O: BitOrder,
T: BitStore,
sourcefn get(
self,
bits: <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Immut
) -> Option<<RangeTo<usize> as BitSliceIndex<'a, T, O>>::Immut>
fn get(
self,
bits: <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Immut
) -> Option<<RangeTo<usize> as BitSliceIndex<'a, T, O>>::Immut>
Immutably indexes into a bit-slice, returning None if self is out of
bounds. Read more
sourcefn get_mut(
self,
bits: <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Mut
) -> Option<<RangeTo<usize> as BitSliceIndex<'a, T, O>>::Mut>
fn get_mut(
self,
bits: <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Mut
) -> Option<<RangeTo<usize> as BitSliceIndex<'a, T, O>>::Mut>
Mutably indexes into a bit-slice, returning None if self is out of
bounds. Read more
sourceunsafe fn get_unchecked(
self,
bits: <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Immut
) -> <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Immut
unsafe fn get_unchecked(
self,
bits: <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Immut
) -> <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Immut
Immutably indexes into a bit-slice without doing any bounds checking. Read more
sourceunsafe fn get_unchecked_mut(
self,
bits: <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Mut
) -> <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Mut
unsafe fn get_unchecked_mut(
self,
bits: <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Mut
) -> <RangeTo<usize> as BitSliceIndex<'a, T, O>>::Mut
Mutably indexes into a bit-slice without doing any bounds checking. Read more
sourceimpl<T, O> Index<RangeTo<usize>> for BitSlice<T, O> where
O: BitOrder,
T: BitStore,
impl<T, O> Index<RangeTo<usize>> for BitSlice<T, O> where
O: BitOrder,
T: BitStore,
sourcefn index(
&self,
index: RangeTo<usize>
) -> &<BitSlice<T, O> as Index<RangeTo<usize>>>::OutputⓘNotable traits for &'_ mut BitSlice<T, O>impl<'_, T, O> Write for &'_ mut BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
fn index(
&self,
index: RangeTo<usize>
) -> &<BitSlice<T, O> as Index<RangeTo<usize>>>::OutputⓘNotable traits for &'_ mut BitSlice<T, O>impl<'_, T, O> Write for &'_ mut BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
Performs the indexing (container[index]) operation. Read more
sourceimpl<T, O> IndexMut<RangeTo<usize>> for BitSlice<T, O> where
O: BitOrder,
T: BitStore,
impl<T, O> IndexMut<RangeTo<usize>> for BitSlice<T, O> where
O: BitOrder,
T: BitStore,
sourcefn index_mut(
&mut self,
index: RangeTo<usize>
) -> &mut <BitSlice<T, O> as Index<RangeTo<usize>>>::OutputⓘNotable traits for &'_ mut BitSlice<T, O>impl<'_, T, O> Write for &'_ mut BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
fn index_mut(
&mut self,
index: RangeTo<usize>
) -> &mut <BitSlice<T, O> as Index<RangeTo<usize>>>::OutputⓘNotable traits for &'_ mut BitSlice<T, O>impl<'_, T, O> Write for &'_ mut BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
Performs the mutable indexing (container[index]) operation. Read more
1.28.0 · sourceimpl<T> RangeBounds<T> for RangeTo<T>
impl<T> RangeBounds<T> for RangeTo<T>
1.28.0 · sourceimpl<'_, T> RangeBounds<T> for RangeTo<&'_ T>
impl<'_, T> RangeBounds<T> for RangeTo<&'_ T>
1.15.0 (const: unstable) · sourceimpl<T> SliceIndex<[T]> for RangeTo<usize>
impl<T> SliceIndex<[T]> for RangeTo<usize>
const: unstable · sourcefn get(self, slice: &[T]) -> Option<&[T]>
fn get(self, slice: &[T]) -> Option<&[T]>
slice_index_methods)Returns a shared reference to the output at this location, if in bounds. Read more
const: unstable · sourcefn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
fn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
slice_index_methods)Returns a mutable reference to the output at this location, if in bounds. Read more
const: unstable · sourceunsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
unsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
slice_index_methods)Returns a shared reference to the output at this location, without
performing any bounds checking.
Calling this method with an out-of-bounds index or a dangling slice pointer
is undefined behavior even if the resulting reference is not used. Read more
const: unstable · sourceunsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
unsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
slice_index_methods)Returns a mutable reference to the output at this location, without
performing any bounds checking.
Calling this method with an out-of-bounds index or a dangling slice pointer
is undefined behavior even if the resulting reference is not used. Read more
const: unstable · sourcefn index(self, slice: &[T]) -> &[T]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]
fn index(self, slice: &[T]) -> &[T]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]
slice_index_methods)Returns a shared reference to the output at this location, panicking if out of bounds. Read more
const: unstable · sourcefn index_mut(self, slice: &mut [T]) -> &mut [T]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]
fn index_mut(self, slice: &mut [T]) -> &mut [T]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]
slice_index_methods)Returns a mutable reference to the output at this location, panicking if out of bounds. Read more
1.20.0 (const: unstable) · sourceimpl SliceIndex<str> for RangeTo<usize>
impl SliceIndex<str> for RangeTo<usize>
Implements substring slicing with syntax &self[.. end] or &mut self[.. end].
Returns a slice of the given string from the byte range [0, end).
Equivalent to &self[0 .. end] or &mut self[0 .. end].
This operation is O(1).
Prior to 1.20.0, these indexing operations were still supported by
direct implementation of Index and IndexMut.
Panics
Panics if end does not point to the starting byte offset of a
character (as defined by is_char_boundary), or if end > len.
const: unstable · sourcefn get(
self,
slice: &str
) -> Option<&<RangeTo<usize> as SliceIndex<str>>::Output>
fn get(
self,
slice: &str
) -> Option<&<RangeTo<usize> as SliceIndex<str>>::Output>
slice_index_methods)Returns a shared reference to the output at this location, if in bounds. Read more
const: unstable · sourcefn get_mut(
self,
slice: &mut str
) -> Option<&mut <RangeTo<usize> as SliceIndex<str>>::Output>
fn get_mut(
self,
slice: &mut str
) -> Option<&mut <RangeTo<usize> as SliceIndex<str>>::Output>
slice_index_methods)Returns a mutable reference to the output at this location, if in bounds. Read more
const: unstable · sourceunsafe fn get_unchecked(
self,
slice: *const str
) -> *const <RangeTo<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked(
self,
slice: *const str
) -> *const <RangeTo<usize> as SliceIndex<str>>::Output
slice_index_methods)Returns a shared reference to the output at this location, without
performing any bounds checking.
Calling this method with an out-of-bounds index or a dangling slice pointer
is undefined behavior even if the resulting reference is not used. Read more
const: unstable · sourceunsafe fn get_unchecked_mut(
self,
slice: *mut str
) -> *mut <RangeTo<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked_mut(
self,
slice: *mut str
) -> *mut <RangeTo<usize> as SliceIndex<str>>::Output
slice_index_methods)Returns a mutable reference to the output at this location, without
performing any bounds checking.
Calling this method with an out-of-bounds index or a dangling slice pointer
is undefined behavior even if the resulting reference is not used. Read more
impl<Idx> Copy for RangeTo<Idx> where
Idx: Copy,
impl<Idx> Eq for RangeTo<Idx> where
Idx: Eq,
impl<T> OneSidedRange<T> for RangeTo<T> where
RangeTo<T>: RangeBounds<T>,
impl<Idx> StructuralEq for RangeTo<Idx>
impl<Idx> StructuralPartialEq for RangeTo<Idx>