Struct scale_info::Field
source · [−]Expand description
A field of a struct-like data type.
Name is optional so it can represent both named and unnamed fields.
This can be a named field of a struct type or an enum struct variant, or an unnamed field of a tuple struct.
Type name
The type_name field contains a string which is the name of the type of the
field as it appears in the source code. The exact contents and format of the
type name are not specified, but in practice will be the name of any valid
type for a field e.g.
- Concrete types e.g
"u32","bool","Foo"etc. - Type parameters e.g
"T","U" - Generic types e.g
"Vec<u32>","Vec<T>" - Associated types e.g.
"T::MyType","<T as MyTrait>::MyType" - Type aliases e.g.
"MyTypeAlias","MyTypeAlias<T>" - Other built in Rust types e.g. arrays, references etc.
Note that the type name doesn’t correspond to the underlying type of the field, unless using a concrete type directly. Any given type may be referred to by multiple field type names, when using generic type parameters and type aliases.
This is intended for informational and diagnostic purposes only. Although it is possible to infer certain properties e.g. whether a type name is a type alias, there are no guarantees provided, and the type name representation may change.
Implementations
sourceimpl<T> Field<T>where
T: Form,
impl<T> Field<T>where
T: Form,
sourcepub fn builder() -> FieldBuilder<T>
pub fn builder() -> FieldBuilder<T>
Returns a new FieldBuilder for constructing a field.
sourceimpl<T> Field<T>where
T: Form,
impl<T> Field<T>where
T: Form,
sourcepub fn name(&self) -> Option<&T::String>
pub fn name(&self) -> Option<&T::String>
Returns the name of the field. None for unnamed fields.
sourcepub fn type_name(&self) -> Option<&T::String>
pub fn type_name(&self) -> Option<&T::String>
Returns a string which is the name of the type of the field as it appears in the source code. The exact contents and format of the type name are not specified, but in practice will be the name of any valid type for a field. This is intended for informational and diagnostic purposes only.