Struct scale_info::prelude::ops::RangeToInclusive
1.26.0 · source · [−]pub struct RangeToInclusive<Idx> {
pub end: Idx,
}Expand description
A range only bounded inclusively above (..=end).
The RangeToInclusive ..=end contains all values with x <= end.
It cannot serve as an Iterator because it doesn’t have a starting point.
Examples
The ..=end syntax is a RangeToInclusive:
assert_eq!((..=5), std::ops::RangeToInclusive{ end: 5 });It does not have an IntoIterator implementation, so you can’t use it in a
for loop directly. This won’t compile:
// error[E0277]: the trait bound `std::ops::RangeToInclusive<{integer}>:
// std::iter::Iterator` is not satisfied
for i in ..=5 {
// ...
}When used as a slicing index, RangeToInclusive produces a slice of all
array elements up to and including the index indicated by end.
let arr = [0, 1, 2, 3, 4];
assert_eq!(arr[ .. ], [0, 1, 2, 3, 4]);
assert_eq!(arr[ .. 3], [0, 1, 2 ]);
assert_eq!(arr[ ..=3], [0, 1, 2, 3 ]); // This is a `RangeToInclusive`
assert_eq!(arr[1.. ], [ 1, 2, 3, 4]);
assert_eq!(arr[1.. 3], [ 1, 2 ]);
assert_eq!(arr[1..=3], [ 1, 2, 3 ]);Fields
end: IdxThe upper bound of the range (inclusive)
Implementations
sourceimpl<Idx> RangeToInclusive<Idx> where
Idx: PartialOrd<Idx>,
impl<Idx> RangeToInclusive<Idx> where
Idx: PartialOrd<Idx>,
1.35.0 · sourcepub fn contains<U>(&self, item: &U) -> bool where
Idx: PartialOrd<U>,
U: PartialOrd<Idx> + ?Sized,
pub fn contains<U>(&self, item: &U) -> bool where
Idx: PartialOrd<U>,
U: PartialOrd<Idx> + ?Sized,
Returns true if item is contained in the range.
Examples
assert!( (..=5).contains(&-1_000_000_000));
assert!( (..=5).contains(&5));
assert!(!(..=5).contains(&6));
assert!( (..=1.0).contains(&1.0));
assert!(!(..=1.0).contains(&f32::NAN));
assert!(!(..=f32::NAN).contains(&0.5));Trait Implementations
sourceimpl<'a, T, O> BitSliceIndex<'a, T, O> for RangeToInclusive<usize> where
O: BitOrder,
T: BitStore,
impl<'a, T, O> BitSliceIndex<'a, T, O> for RangeToInclusive<usize> where
O: BitOrder,
T: BitStore,
sourcefn get(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut
) -> Option<<RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut>
fn get(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut
) -> Option<<RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut>
Immutably indexes into a bit-slice, returning None if self is out of
bounds. Read more
sourcefn get_mut(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut
) -> Option<<RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut>
fn get_mut(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut
) -> Option<<RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut>
Mutably indexes into a bit-slice, returning None if self is out of
bounds. Read more
sourceunsafe fn get_unchecked(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut
) -> <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut
unsafe fn get_unchecked(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut
) -> <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut
Immutably indexes into a bit-slice without doing any bounds checking. Read more
sourceunsafe fn get_unchecked_mut(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut
) -> <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut
unsafe fn get_unchecked_mut(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut
) -> <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut
Mutably indexes into a bit-slice without doing any bounds checking. Read more
sourcefn index(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut
) -> <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut
fn index(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut
) -> <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Immut
Immutably indexes into a bit-slice, panicking if self is out of
bounds. Read more
sourcefn index_mut(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut
) -> <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut
fn index_mut(
self,
bits: <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut
) -> <RangeToInclusive<usize> as BitSliceIndex<'a, T, O>>::Mut
Mutably indexes into a bit-slice, panicking if self is out of bounds. Read more
sourceimpl<Idx> Clone for RangeToInclusive<Idx> where
Idx: Clone,
impl<Idx> Clone for RangeToInclusive<Idx> where
Idx: Clone,
sourcefn clone(&self) -> RangeToInclusive<Idx>
fn clone(&self) -> RangeToInclusive<Idx>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl<Idx> Debug for RangeToInclusive<Idx> where
Idx: Debug,
impl<Idx> Debug for RangeToInclusive<Idx> where
Idx: Debug,
sourceimpl<Idx> Hash for RangeToInclusive<Idx> where
Idx: Hash,
impl<Idx> Hash for RangeToInclusive<Idx> where
Idx: Hash,
sourceimpl Index<RangeToInclusive<usize>> for String
impl Index<RangeToInclusive<usize>> for String
sourceimpl<T, O> Index<RangeToInclusive<usize>> for BitSlice<T, O> where
O: BitOrder,
T: BitStore,
impl<T, O> Index<RangeToInclusive<usize>> for BitSlice<T, O> where
O: BitOrder,
T: BitStore,
sourcefn index(
&self,
index: RangeToInclusive<usize>
) -> &<BitSlice<T, O> as Index<RangeToInclusive<usize>>>::OutputⓘNotable traits for &'_ mut BitSlice<T, O>impl<'_, T, O> Write for &'_ mut BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
fn index(
&self,
index: RangeToInclusive<usize>
) -> &<BitSlice<T, O> as Index<RangeToInclusive<usize>>>::OutputⓘNotable traits for &'_ mut BitSlice<T, O>impl<'_, T, O> Write for &'_ mut BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
Performs the indexing (container[index]) operation. Read more
sourceimpl IndexMut<RangeToInclusive<usize>> for String
impl IndexMut<RangeToInclusive<usize>> for String
sourceimpl<T, O> IndexMut<RangeToInclusive<usize>> for BitSlice<T, O> where
O: BitOrder,
T: BitStore,
impl<T, O> IndexMut<RangeToInclusive<usize>> for BitSlice<T, O> where
O: BitOrder,
T: BitStore,
sourcefn index_mut(
&mut self,
index: RangeToInclusive<usize>
) -> &mut <BitSlice<T, O> as Index<RangeToInclusive<usize>>>::OutputⓘNotable traits for &'_ mut BitSlice<T, O>impl<'_, T, O> Write for &'_ mut BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
fn index_mut(
&mut self,
index: RangeToInclusive<usize>
) -> &mut <BitSlice<T, O> as Index<RangeToInclusive<usize>>>::OutputⓘNotable traits for &'_ mut BitSlice<T, O>impl<'_, T, O> Write for &'_ mut BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField, impl<'_, T, O> Read for &'_ BitSlice<T, O> where
T: BitStore,
O: BitOrder,
BitSlice<T, O>: BitField,
Performs the mutable indexing (container[index]) operation. Read more
sourceimpl<Idx> PartialEq<RangeToInclusive<Idx>> for RangeToInclusive<Idx> where
Idx: PartialEq<Idx>,
impl<Idx> PartialEq<RangeToInclusive<Idx>> for RangeToInclusive<Idx> where
Idx: PartialEq<Idx>,
sourcefn eq(&self, other: &RangeToInclusive<Idx>) -> bool
fn eq(&self, other: &RangeToInclusive<Idx>) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &RangeToInclusive<Idx>) -> bool
fn ne(&self, other: &RangeToInclusive<Idx>) -> bool
This method tests for !=.
1.28.0 · sourceimpl<T> RangeBounds<T> for RangeToInclusive<T>
impl<T> RangeBounds<T> for RangeToInclusive<T>
1.28.0 · sourceimpl<'_, T> RangeBounds<T> for RangeToInclusive<&'_ T>
impl<'_, T> RangeBounds<T> for RangeToInclusive<&'_ T>
const: unstable · sourceimpl<T> SliceIndex<[T]> for RangeToInclusive<usize>
impl<T> SliceIndex<[T]> for RangeToInclusive<usize>
const: unstable · sourcefn get(self, slice: &[T]) -> Option<&[T]>
fn get(self, slice: &[T]) -> Option<&[T]>
slice_index_methods)Returns a shared reference to the output at this location, if in bounds. Read more
const: unstable · sourcefn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
fn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
slice_index_methods)Returns a mutable reference to the output at this location, if in bounds. Read more
const: unstable · sourceunsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
unsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
slice_index_methods)Returns a shared reference to the output at this location, without
performing any bounds checking.
Calling this method with an out-of-bounds index or a dangling slice pointer
is undefined behavior even if the resulting reference is not used. Read more
const: unstable · sourceunsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
unsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
slice_index_methods)Returns a mutable reference to the output at this location, without
performing any bounds checking.
Calling this method with an out-of-bounds index or a dangling slice pointer
is undefined behavior even if the resulting reference is not used. Read more
const: unstable · sourcefn index(self, slice: &[T]) -> &[T]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]
fn index(self, slice: &[T]) -> &[T]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]
slice_index_methods)Returns a shared reference to the output at this location, panicking if out of bounds. Read more
const: unstable · sourcefn index_mut(self, slice: &mut [T]) -> &mut [T]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]
fn index_mut(self, slice: &mut [T]) -> &mut [T]ⓘNotable traits for &'_ [u8]impl<'_> Read for &'_ [u8]impl<'_> Write for &'_ mut [u8]
slice_index_methods)Returns a mutable reference to the output at this location, panicking if out of bounds. Read more
const: unstable · sourceimpl SliceIndex<str> for RangeToInclusive<usize>
impl SliceIndex<str> for RangeToInclusive<usize>
Implements substring slicing with syntax &self[..= end] or &mut self[..= end].
Returns a slice of the given string from the byte range [0, end].
Equivalent to &self [0 .. end + 1], except if end has the maximum
value for usize.
This operation is O(1).
Panics
Panics if end does not point to the ending byte offset of a character
(end + 1 is either a starting byte offset as defined by
is_char_boundary, or equal to len), or if end >= len.
const: unstable · sourcefn get(
self,
slice: &str
) -> Option<&<RangeToInclusive<usize> as SliceIndex<str>>::Output>
fn get(
self,
slice: &str
) -> Option<&<RangeToInclusive<usize> as SliceIndex<str>>::Output>
slice_index_methods)Returns a shared reference to the output at this location, if in bounds. Read more
const: unstable · sourcefn get_mut(
self,
slice: &mut str
) -> Option<&mut <RangeToInclusive<usize> as SliceIndex<str>>::Output>
fn get_mut(
self,
slice: &mut str
) -> Option<&mut <RangeToInclusive<usize> as SliceIndex<str>>::Output>
slice_index_methods)Returns a mutable reference to the output at this location, if in bounds. Read more
const: unstable · sourceunsafe fn get_unchecked(
self,
slice: *const str
) -> *const <RangeToInclusive<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked(
self,
slice: *const str
) -> *const <RangeToInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)Returns a shared reference to the output at this location, without
performing any bounds checking.
Calling this method with an out-of-bounds index or a dangling slice pointer
is undefined behavior even if the resulting reference is not used. Read more
const: unstable · sourceunsafe fn get_unchecked_mut(
self,
slice: *mut str
) -> *mut <RangeToInclusive<usize> as SliceIndex<str>>::Output
unsafe fn get_unchecked_mut(
self,
slice: *mut str
) -> *mut <RangeToInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)Returns a mutable reference to the output at this location, without
performing any bounds checking.
Calling this method with an out-of-bounds index or a dangling slice pointer
is undefined behavior even if the resulting reference is not used. Read more
const: unstable · sourcefn index(
self,
slice: &str
) -> &<RangeToInclusive<usize> as SliceIndex<str>>::Output
fn index(
self,
slice: &str
) -> &<RangeToInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)Returns a shared reference to the output at this location, panicking if out of bounds. Read more
const: unstable · sourcefn index_mut(
self,
slice: &mut str
) -> &mut <RangeToInclusive<usize> as SliceIndex<str>>::Output
fn index_mut(
self,
slice: &mut str
) -> &mut <RangeToInclusive<usize> as SliceIndex<str>>::Output
slice_index_methods)Returns a mutable reference to the output at this location, panicking if out of bounds. Read more
impl<Idx> Copy for RangeToInclusive<Idx> where
Idx: Copy,
impl<Idx> Eq for RangeToInclusive<Idx> where
Idx: Eq,
impl<T> OneSidedRange<T> for RangeToInclusive<T> where
RangeToInclusive<T>: RangeBounds<T>,
impl<Idx> StructuralEq for RangeToInclusive<Idx>
impl<Idx> StructuralPartialEq for RangeToInclusive<Idx>