Struct scale_info::Path
source · [−]Expand description
Represents the path of a type definition.
This consists of several segments that each have to be a valid Rust
identifier. The first segment represents the crate name in which the type
has been defined. The last segment is the identifier accessed with ident().
Rust prelude type may have an empty namespace definition.
Implementations
sourceimpl Path
impl Path
sourcepub fn from_segments<I>(segments: I) -> Result<Path, PathError>where
I: IntoIterator<Item = &'static str>,
pub fn from_segments<I>(segments: I) -> Result<Path, PathError>where
I: IntoIterator<Item = &'static str>,
Create a Path from the given segments
Errors
- If no segments are supplied
- If any of the segments are invalid Rust identifiers