Struct scale_info::TypeDefBitSequence
source · [−]Expand description
Type describing a [bitvec::vec::BitVec].
Note
This can only be constructed for TypeInfo in the MetaForm with the bit-vec feature
enabled, but can be decoded or deserialized into the PortableForm without this feature.
Implementations
sourceimpl<T> TypeDefBitSequence<T>where
T: Form,
impl<T> TypeDefBitSequence<T>where
T: Form,
sourcepub fn bit_order_type(&self) -> &T::Type
pub fn bit_order_type(&self) -> &T::Type
Returns the type of the bit ordering of the [::bitvec::vec::BitVec].
sourcepub fn bit_store_type(&self) -> &T::Type
pub fn bit_store_type(&self) -> &T::Type
Returns underlying type used to store the [::bitvec::vec::BitVec].
sourceimpl TypeDefBitSequence
impl TypeDefBitSequence
sourcepub fn new<Store, Order>() -> Selfwhere
Store: TypeInfo + 'static,
Order: TypeInfo + 'static,
pub fn new<Store, Order>() -> Selfwhere
Store: TypeInfo + 'static,
Order: TypeInfo + 'static,
Creates a new TypeDefBitSequence for the supplied bit order and bit store types.
With the bit-vec feature enabled, the expected usage is to provide either
bitvec::order::Lsb0 or bitvec::order::Msb0 as the order type, and then something
like u8, u8, or u32 as the store type. Without the bit-vec feature enabled, it’s
recommended that your types have identical TypeInfo to those.
sourceimpl TypeDefBitSequence<PortableForm>
impl TypeDefBitSequence<PortableForm>
sourcepub fn new_portable(
bit_store_type: <PortableForm as Form>::Type,
bit_order_type: <PortableForm as Form>::Type
) -> Self
pub fn new_portable(
bit_store_type: <PortableForm as Form>::Type,
bit_order_type: <PortableForm as Form>::Type
) -> Self
Creates a new TypeDefBitSequence for the supplied bit order and bit store types.